@@ -9,9 +9,9 @@ System System1985 = {
   .RATES = { 0, 0.2667, 0.3, 0.46, 0.4733, 0.5533, 0.6, 0.6 },
   .M = {
     .lwr_single = 7111,
-    .upr_single = 8366,
+    .upr_single = 7485, //8366,
     .lwr_family = 11804,
-    .upr_family = 13888,
+    .upr_family = 12426, //13888,
     .has_sapto_thr = true,
     .sapto_age = 65,
     .lwr_single_sapto = 1985,
