@@ -26,14 +26,17 @@ System System2012 = {
   },
   .has_sapto = true,
   .S = {
-    .year = 2014,
+    .year = 2012,
     .pension_age = 65,
     .mxo_single = 2230,
     .mxo_couple = 1602,
-    .lwr_single = 30685,
+    .mxo_illness = 2040,
+    .lwr_single = 32279,
     .lwr_couple = 28974,
-    .upr_single = 48525,
-    .upr_couple = 41790,
+    .lwr_illness = 31279,
+    .upr_single = 50119,
+    .upr_couple = 83580,
+    .upr_illness = 95198,
     .taper = 0.125,
     .first_tax_rate = 0.15,
     .second_tax_rate = 0.30,
